{%- set os=grains['os'] -%}

laradev-unzip:
  pkg.installed:
    - name: unzip
laradev-php:
  pkg.installed:
    - name: php
laradev-composer:
  pkg.installed:
    - name: composer
laradev-php-fpm:
  pkg.installed:
    - name: php-fpm
  service.running:
    - name: php-fpm
    - enable: true
    - watch:
      - file: /etc/php/php.ini
      
laradev-sqlite:
  pkg.installed:
    - name: sqlite
laradev-phpsqlite:
  pkg.installed:
    - name: php-sqlite
laradev-phpxsl:
  pkg.installed:
    - name: php-xsl

database-directory:
  file.directory:
    - name: /sites/databases
    - makedirs: true
/var/lib/mysql:
  file.symlink:
      - target: /sites/databases/
laradev-mysql:
  pkg.installed:
    - name: mariadb
laradev-mysql-python:
  pkg.installed:
    - name: mysql-python
laradev-init-mysql:
  cmd.run:
    - name: mysql_install_db --user=mysql --basedir=/usr --datadir=/sites/databases/
    - unless: 'test -e /sites/databases/mysql'
laradev-mysql-service:
  service.running:
    - name: mysqld
    - enable: true

#create laradev user
laradev-user:
  mysql_user.present:
    - name: laradev
    - host: "localhost"
    - password: "secret"
    - connection_user: root

laradev-nginx-conf:
  file.managed:
    - name: /etc/nginx/nginx.conf
    - source: salt://roles/maintain/nginx-proxy/nginx.conf
    - user: root
    - group: root
    - mode: 644

{%- if pillar['laradev'] is defined -%}
{%- for server in pillar['laradev'] %}
"/etc/nginx/certs/{{server}}.actcur.com/":
  file.recurse:
    - source: salt://secure/certs/{{server}}.actcur.com/
{%- if os=="CentOS" or os=="RedHat" %}
    - user: nginx
    - user: nginx
{%- elif os=="Arch" or os=="Manjaro" %}
    - user: http
    - group: http
{%- endif %}
    - dir_mode: 755
    - file_mode: 400
    - clean: true

/etc/nginx/conf.d/{{ server }}.conf:
  file.managed:
    - makedirs: true
    - source: salt://roles/maintain/laradev/nginx.conf
    - user: root
    - group: root
    - mode: 644
    - template: jinja
    - context:
      server: {{ server }}
      
{% endfor %}
{% endif %}

/etc/php/php.ini:
  file.managed:
    - source: salt://roles/maintain/laradev/php.ini
    - user: root
    - group: root
    - mode: 644

/root/scripts/git_branches.sh:
  file.managed:
    - source: salt://roles/maintain/laradev/git_branches.sh
    - user: root
    - group: root
    - mode: 644
    - template: jinja

"/lib/systemd/system/git_branches.service":
  file.managed:
    - source: salt://roles/maintain/laradev/git_branches.service
    - user: root
    - group: root
    - mode: 644

"/lib/systemd/system/git_branches.timer":
  file.managed:
    - source: salt://roles/maintain/laradev/git_branches.timer
    - user: root
    - group: root
    - mode: 644

"git_branches-reload":
  module.run:
    - name: service.systemctl_reload
    - onchanges:
      - file: /lib/systemd/system/*

"git_branches.timer":
  service.running:
    - enable: true
